@@ -6,7 +6,8 @@
 #' @return No return value, called for side effects
 #' @export
 print.psFit = function(x, ...){
-  cat(paste("The estimated shape parameter was ", x$shape, "\n"))
+  cat(paste("The estimated shape parameter is ", x$shape, "\n"))
+  cat(paste("The the standard error of shape parameter is ", sqrt(x$var.shape), "\n"))
   cat(paste("The first ", length(x$fitted), "fitted values are:\n"))
   print(x$fitted)
 }
